<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>BoolEdit</name>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booleano</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nome</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valore:</translation>
    </message>
    <message>
        <source>True</source>
        <translation type="obsolete">Vero</translation>
    </message>
    <message>
        <source>False</source>
        <translation type="obsolete">Falso</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Attivo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annulla</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>DoubleEdit</name>
    <message>
        <source>Double</source>
        <translation type="obsolete">Reale</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valore:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nome</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Attivo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt-O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annulla</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>IntEdit</name>
    <message>
        <source>Int</source>
        <translation type="obsolete">Intero</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valore:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nome</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Attivo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annulla</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>LanguageOptions</name>
    <message>
        <location filename="languageoptions.cpp" line="74"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
</context>
<context>
    <name>ListEdit</name>
    <message>
        <source>String</source>
        <translation type="obsolete">Stringa</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Intero</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Reale</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booleano</translation>
    </message>
    <message>
        <source>List</source>
        <translation type="obsolete">Lista</translation>
    </message>
    <message>
        <source>Unknown Type</source>
        <translation type="obsolete">Tipo sconosciuto</translation>
    </message>
    <message>
        <source>I do not understand the type %1.</source>
        <translation type="obsolete">Non riconosco il tipo %1.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Attenzione</translation>
    </message>
    <message>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="obsolete">Non so come modificare il tipo QVariant %1.</translation>
    </message>
    <message>
        <source>The item you selected is not a QListBoxVariant item. I do not know what to do.</source>
        <translation type="obsolete">L&apos;elemento selezionato non è un QListBoxVariant. Non so cosa fare.</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Attivo</translation>
    </message>
    <message>
        <source>Values:</source>
        <translation type="obsolete">Valori:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nome</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annulla</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Nuovo</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="obsolete">&amp;Sposta Sù</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+S</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Modifica</translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation type="obsolete">Alt+M</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="obsolete">Sposta &amp;Giù</translation>
    </message>
    <message>
        <source>Alt+D</source>
        <translation type="obsolete">Alt+G</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Elimina</translation>
    </message>
</context>
<context>
    <name>NewVariant</name>
    <message>
        <source>New Variant</source>
        <translation type="obsolete">Nouveau type (Variant)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Tipo:</translation>
    </message>
    <message>
        <source>String</source>
        <translation type="obsolete">Stringa</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Intero</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Reale</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booleano</translation>
    </message>
    <message>
        <source>List</source>
        <translation type="obsolete">Lista</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annulla</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>ParamListEdit</name>
    <message>
        <location filename="paramlistedit.ui" line="30"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="41"/>
        <source>List:</source>
        <translation>Lista:</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="64"/>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="71"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>ParameterEdit</name>
    <message>
        <location filename="parameteredit.ui" line="38"/>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="43"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="48"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="53"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="187"/>
        <source>Name already exists</source>
        <translation>Il nome esiste già</translation>
    </message>
    <message>
        <source>The name for the parameter you specified already exists in the list.</source>
        <translation type="obsolete">Il nome del parametro esiste già nella lista.</translation>
    </message>
    <message>
        <source>String</source>
        <translation type="obsolete">Stringa</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Intero</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Reale</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Booleano</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="113"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <source>Unknown Type</source>
        <translation type="obsolete">Tipo sconosciuto</translation>
    </message>
    <message>
        <source>I do not understand the type %1.</source>
        <translation type="obsolete">Non riconosco il tipo %1.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Attenzione</translation>
    </message>
    <message>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="obsolete">Non so come modificare il tipo QVariant %1.</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="31"/>
        <source>Parameter List</source>
        <translation>Lista dei parametri</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="63"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="66"/>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="73"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="76"/>
        <source>Alt+C</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="93"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="96"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="103"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="106"/>
        <location filename="parameteredit.ui" line="116"/>
        <source>Alt+E</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="123"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="75"/>
        <source>Not a Valid Report</source>
        <translation>Report non valido</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="76"/>
        <source>The report definition does not appear to be a valid report.

The root node is not &apos;report&apos;.</source>
        <translation>La definizione del report non sembra essere un report valido.

La nodo radice non è &apos;report&apos;.</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="188"/>
        <source>&lt;p&gt;The name for the parameter you specified already exists in the list.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ParameterProperties</name>
    <message>
        <location filename="parameterproperties.ui" line="14"/>
        <source>Parameter Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="20"/>
        <source>Type:</source>
        <translation type="unfinished">Tipo:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="34"/>
        <location filename="parameterproperties.cpp" line="107"/>
        <location filename="parameterproperties.cpp" line="207"/>
        <location filename="parameterproperties.cpp" line="274"/>
        <location filename="parameterproperties.cpp" line="301"/>
        <source>String</source>
        <translation type="unfinished">Stringa</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="39"/>
        <location filename="parameterproperties.cpp" line="95"/>
        <location filename="parameterproperties.cpp" line="198"/>
        <location filename="parameterproperties.cpp" line="280"/>
        <location filename="parameterproperties.cpp" line="307"/>
        <source>Bool</source>
        <translation type="unfinished">Booleano</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="44"/>
        <location filename="parameterproperties.cpp" line="99"/>
        <location filename="parameterproperties.cpp" line="201"/>
        <location filename="parameterproperties.cpp" line="276"/>
        <location filename="parameterproperties.cpp" line="303"/>
        <source>Int</source>
        <translation type="unfinished">Intero</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="49"/>
        <location filename="parameterproperties.cpp" line="103"/>
        <location filename="parameterproperties.cpp" line="204"/>
        <location filename="parameterproperties.cpp" line="278"/>
        <location filename="parameterproperties.cpp" line="305"/>
        <source>Double</source>
        <translation type="unfinished">Reale</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="54"/>
        <location filename="parameterproperties.cpp" line="111"/>
        <location filename="parameterproperties.cpp" line="210"/>
        <location filename="parameterproperties.cpp" line="282"/>
        <location filename="parameterproperties.cpp" line="309"/>
        <source>List</source>
        <translation type="unfinished">Lista</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="72"/>
        <source>Name:</source>
        <translation type="unfinished">Nome:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="95"/>
        <location filename="parameterproperties.ui" line="115"/>
        <location filename="parameterproperties.ui" line="155"/>
        <location filename="parameterproperties.ui" line="175"/>
        <source>Value:</source>
        <translation type="unfinished">Valore:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="135"/>
        <source>False</source>
        <translation type="unfinished">Falso</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="140"/>
        <source>True</source>
        <translation type="unfinished">Vero</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="192"/>
        <source>Values:</source>
        <translation type="unfinished">Valori:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="210"/>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="213"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="230"/>
        <source>Move &amp;Up</source>
        <translation type="unfinished">&amp;Sposta Sù</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="233"/>
        <source>Alt+U</source>
        <translation type="unfinished">Alt+S</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="240"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Modifica</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="243"/>
        <source>Alt+E</source>
        <translation type="unfinished">Alt+M</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="250"/>
        <source>Move &amp;Down</source>
        <translation type="unfinished">Sposta &amp;Giù</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="253"/>
        <source>Alt+D</source>
        <translation type="unfinished">Alt+G</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="270"/>
        <source>Delete</source>
        <translation type="unfinished">Elimina</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="299"/>
        <source>Active</source>
        <translation type="unfinished">Attivo</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="115"/>
        <location filename="parameterproperties.cpp" line="188"/>
        <location filename="parameterproperties.cpp" line="213"/>
        <source>Warning</source>
        <translation type="unfinished">Attenzione</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="116"/>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="unfinished">Non so come modificare il tipo QVariant %1.</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="189"/>
        <location filename="parameterproperties.cpp" line="214"/>
        <source>I do not recognize type %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="285"/>
        <location filename="parameterproperties.cpp" line="312"/>
        <source>Unknown Type</source>
        <translation type="unfinished">Tipo sconosciuto</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="286"/>
        <location filename="parameterproperties.cpp" line="313"/>
        <source>I do not understand the type %1.</source>
        <translation type="unfinished">Non riconosco il tipo %1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="data.cpp" line="25"/>
        <source>%1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="data.cpp" line="26"/>
        <source>Copyright (c) 2002-2012, OpenMFG, LLC.</source>
        <oldsource>Copyright (c) 2002-2011, OpenMFG, LLC.</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="data.cpp" line="28"/>
        <source>3.3.4</source>
        <oldsource>3.3.1</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StringEdit</name>
    <message>
        <source>String</source>
        <translation type="obsolete">Stringa</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Valore:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nome</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Attivo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annulla</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+A</translation>
    </message>
</context>
<context>
    <name>login</name>
    <message>
        <location filename="login.cpp" line="146"/>
        <source>Initializing the Database Connector</source>
        <translation>Inizializzazione connessione Database</translation>
    </message>
    <message>
        <location filename="login.cpp" line="159"/>
        <source>No Database Driver</source>
        <translation>Driver Database mancante</translation>
    </message>
    <message>
        <location filename="login.cpp" line="160"/>
        <source>A connection could not be established with the specified
Database as the Proper Database Drivers have not been installed.
Contact your Systems Administrator.
</source>
        <translation>Impossibile stabilire una connessione con il database specificato
in quanto i driver necessari al database non sono stati installati.
Contatta l&apos;amministratore di sistema.
      </translation>
    </message>
    <message>
        <location filename="login.cpp" line="180"/>
        <source>Connecting to the Database</source>
        <translation>Connessione al Database</translation>
    </message>
    <message>
        <location filename="login.cpp" line="193"/>
        <source>Cannot Connect to Database Server</source>
        <translation>Impossibile connettersi con il Database Server</translation>
    </message>
    <message>
        <location filename="login.cpp" line="194"/>
        <source>A connection to the specified Database Server cannot be made.  This may be due to an
incorrect Username and/or Password or that the Database Server in question cannot
support anymore connections.

Please verify your Username and Password and try again or wait until the specified
Database Server is less busy.

System Error &apos;%1&apos;
%2</source>
        <translation>
        La connexion à la base spécifiée est impossible. Ceci peut être dû à un nom d&apos;utilisateur
        ou un mot de passe incorrect ou bien que le serveur en question n&apos;accepte pas de
        connexions supplémentaires.

        Veuillez vérifier votre nom d&apos;utilisateur et mot de passe et réessayer ou attendez que le
        serveur soit moins occupé.

        Erreur système &apos;%1&apos;
        %2
      </translation>
    </message>
    <message>
        <location filename="login.cpp" line="214"/>
        <source>Logging into the Database</source>
        <translation>Autenticazione in corso</translation>
    </message>
    <message>
        <location filename="login.ui" line="31"/>
        <source>Log In</source>
        <translation>Autenticazione</translation>
    </message>
    <message>
        <location filename="login.ui" line="2010"/>
        <source>Build: </source>
        <translation>Build: </translation>
    </message>
    <message>
        <location filename="login.ui" line="2538"/>
        <source>&amp;Username:</source>
        <translation>&amp;Utente:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2551"/>
        <source>&amp;Password:</source>
        <translation>&amp;Password:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2637"/>
        <source>S&amp;erver:</source>
        <translation>S&amp;erver:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2650"/>
        <source>&amp;Database:</source>
        <translation>&amp;Database:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2781"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="login.ui" line="2788"/>
        <source>&amp;Login</source>
        <translation>&amp;Accedi</translation>
    </message>
    <message>
        <location filename="login.ui" line="2801"/>
        <source>&amp;Options</source>
        <translation>&amp;Opzioni</translation>
    </message>
    <message>
        <location filename="login.cpp" line="112"/>
        <source>Version </source>
        <translation>Versione </translation>
    </message>
</context>
<context>
    <name>loginOptions</name>
    <message>
        <location filename="loginOptions.ui" line="31"/>
        <source>Login Options</source>
        <translation>Opzioni di accesso</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="87"/>
        <source>&amp;Database:</source>
        <translation>&amp;Database:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="194"/>
        <source>S&amp;erver:</source>
        <translation>&amp;Server:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="219"/>
        <source>&amp;Port:</source>
        <translation>&amp;Porta:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="246"/>
        <source>Driver:</source>
        <translation>Driver:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="309"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="316"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="260"/>
        <source>PostgreSQL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="265"/>
        <source>ODBC</source>
        <translation></translation>
    </message>
</context>
</TS>
